@@ -391,7 +391,7 @@ const KEYWORDS: &[&str] = &[
     "pub", "in", "const", "static", "match", "use", "mut", "continue", "loop", "break", "if",
     "else",
 ];
-const KEYWORDS2: &[&str] = &["move", "fn", "let", "struct", "enum", "dyn"];
+const KEYWORDS2: &[&str] = &["unsafe", "move", "fn", "let", "struct", "enum", "dyn"];
 
 const SYMBOLS: &[char] = &[':', '&', '?', '+', '-', '*', '/', '=', '!', ',', ';'];
 const TYPES: &[&str] = &[
