@@ -16,7 +16,11 @@ impl ScriptManager4 {
     pub fn new() -> Option<Self> {
         let mut sm = rscript::ScriptManager::default();
         let script_path = dirs_next::config_dir()?.join("irust").join("script4");
-        sm.add_scripts_by_path(script_path).ok()?;
+        sm.add_scripts_by_path(
+            script_path,
+            rscript::Version::Exact(crate::args::VERSION.into()),
+        )
+        .ok()?;
 
         // read conf if available
         let script_conf_path = dirs_next::config_dir()?.join("irust").join("script4.conf");
